@@ -42,6 +42,7 @@ extensions = [
     "sphinx_github_changelog",
     'sphinx_sitemap',
     'sphinx.ext.autosectionlabel',
+    'sphinx.ext.autodoc',
     'sphinx_click',
 ]
 
@@ -108,7 +109,7 @@ html_context = {
     "github_user": "cascode-labs",
     "github_repo": "virtue",
     "github_version": "main",
-    "doc_path": "docs",
+    "doc_path": "docs/source",
 }
 
 html_baseurl = 'http://www.cascode-labs.org/virtue/'
