@@ -1,10 +1,11 @@
-"""Cadence Virtuoso SKILL library"""
+"""Cadence Virtuoso SKILL and Python library"""
 import pluggy
 
 from .LibUtility import *
 from .SchUtility import *
 from .ConfigUtility import *
+from .skill_package.metadata_data import SKillPackageMetadata
 
-__version__ = '0.3.2'
+__version__ = '0.4.0'
 
 hookimpl = pluggy.HookimplMarker("virtue")
